import csp.lang.*;
import csp.lang.Integer;
import java.awt.event.ActionListener;
import csp.io.IOException;

/**
 * This class defines a Call Channel for the Button process. It redirects all public methods of the
 * java.awt.Button class to channel communication.
 */

public class ButtonCallChannel extends Channel implements ButtonCallService, ButtonAcceptService

{
	Channel_of_Proxy toServer   = new Channel_of_Proxy();
	Channel_of_Proxy fromServer = new Channel_of_Proxy();
	Proxy clientproxy = new Proxy();
	Proxy serverproxy = new Proxy();
	int method = 0;
	
	protected final static int ADDNOTIFY						= 1;
	protected final static int GETLABEL							= 2;
	protected final static int SETLABEL							= 3;
	protected final static int SETACTIONCOMMAND			= 4;
	protected final static int GETACTIONCOMMAND			= 5;
	protected final static int ADDACTIONLISTENER		= 6;
	protected final static int REMOVEACTIONLISTENER	= 7;
	
	public ButtonCallChannel()
	{
		super.channel = toServer;
	}
	
	// public methods for the client process
	//---------------------------------------
	public void addNotify() 
	{
		try
		{
			clientproxy.tag = ADDNOTIFY;
			toServer.write(clientproxy);
		}
		catch (IOException e) { }
	}
	
	public String getLabel() 
	{
		try
		{
			clientproxy.tag = GETLABEL;
			toServer.write(clientproxy);
			fromServer.read(clientproxy);
		}
		catch (IOException e) { }
		
		return (String)(clientproxy.object); 
	}
	
	public void setLabel(String label) 
	{
		try
		{
			clientproxy.tag = SETLABEL;
			toServer.write(clientproxy);
			clientproxy.object = label;
			toServer.write(clientproxy);
		}
		catch (IOException e) { }
	}
	
	public void setActionCommand(String command) { /* not implemented yet */ };
	public String getActionCommand() { return null; /* not implemented yet */ };
	public void addActionListener(ActionListener l) { /* not implemented yet */ };
	public void removeActionListener(ActionListener l) { /* not implemented yet */ };
	
	// public method for the server process
	//--------------------------------------
	
	public void accept(ButtonCallService server)
	{
		try
		{
			toServer.read(serverproxy);
			switch(serverproxy.tag)
			{
				case ADDNOTIFY:
					server.addNotify();	
					break;						
				case GETLABEL:
					serverproxy.object = server.getLabel();		
					fromServer.write(serverproxy);
					break;
				case SETLABEL:
					toServer.read(serverproxy);
					server.setLabel((String)(serverproxy.object));
					break;
			}	
		} 
		catch (IOException e) { }
	}
}
